@@ -11,9 +11,10 @@ available under the terms of the BSD License which accompanies
 this distribution, and is available at 
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
-import sys, os
+import sys, os, imp
 
 PYGTK_REQ = '2.0'
+PYATSPI_REQ = (2,23,3)
 GTK_VERSION = (2, 8, 0)
 
 try:
@@ -24,7 +25,7 @@ except KeyError:
   pass
 
 # test for python modules
-modules = ['bonobo', 'ORBit', 'pygtk', 'gtk', 'gtk.glade', 'gtk.gdk', 'wnck']
+modules = ['pygtk', 'gtk', 'gtk.gdk', 'wnck', 'pyatspi']
 for name in modules:
   try:
     m = __import__(name)
@@ -42,14 +43,15 @@ for name in modules:
     m.require('2.0')
   elif name == 'gtk':
     m.check_version(*GTK_VERSION)
+  elif name =='pyatspi':
+    try:
+      compared = map(lambda x: cmp(*x),  zip(PYATSPI_REQ, m.__version__))
+    except AttributeError:
+      # Installed pyatspi does not support __version__, too old.
+      compared = [-1, 0, 0]
+    if -1 in compared and 1 not in compared[:compared.index(-1)]:
+      # A -1 without a 1 preceding it means an older version.
+      print
+      print "Need pyatspi 1.23.4 or higher (or SVN trunk)"
+      sys.exit(1)
 print
-
-# Check pyatspi.
-# TODO: This should be done by comparing versions, for now we
-# will just check the API.
-import pyatspi
-try:
-  pyatspi.Registry.pumpQueuedEvents
-except AttributeError:
-  print 'Newer version of pyatspi required (>= 1.22.0)'
-  sys.exit(1)
